/* 
/*******************************************************************************
 * Copyright (C) 2024 Secretaría General de la Administración Digital, Gobierno de España
 * This program is licensed and may be used, modified and redistributed under the  terms
 * of the European Public License (EUPL), either version 1.1 or (at your option)
 * any later version as soon as they are approved by the European Commission.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and
 * more details.
 * You should have received a copy of the EUPL1.1 license
 * along with this program; if not, you may find it at
 * http:joinup.ec.europa.eu/software/page/eupl/licence-eupl
 ******************************************************************************/

/** 
 * <b>File:</b><p>es.clave.SP2.ClaveSpApplication.java.</p>
 * <b>Description:</b><p>The ClaveSpApplication class is a Spring Boot-based Java application that extends SpringBootServletInitializer.
 * This extension allows the application to be deployed as a WAR both on an external application server (such as Tomcat) and on an embedded server via Spring Boot.
 * This class also serves as the application's starting point through its main method.</p>
 * <b>Project:</b><p>Citizen identification and authentication platform.</p>
 * <b>Date:</b><p>03/10/2024.</p>
 * @author Gobierno de España.
 * @version 1.0, 03/10/2024.
 */
package es.clave.SP2;

import java.util.Arrays;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.builder.SpringApplicationBuilder;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.scheduling.annotation.EnableScheduling;

/** 
 * <p>The ClaveSpApplication class is a Spring Boot-based Java application that extends SpringBootServletInitializer.
 * This extension allows the application to be deployed as a WAR both on an external application server (such as Tomcat) and on an embedded server via Spring Boot.
 * This class also serves as the application's starting point through its main method.</p>
 * <b>Project:</b><p>Citizen identification and authentication platform.</p>
 * @version 1.0, 03/10/2024.
 */
@EnableScheduling
@SpringBootApplication
public class ClaveSpApplication extends SpringBootServletInitializer {

    private static final Logger logger = LoggerFactory.getLogger(ClaveSpApplication.class);

    /**
     * This is the main method that starts the execution of the Spring Boot application.
     * Use SpringApplication.run to start the application context and run any initialization processes.
     * 
     * @param args String[]
     */
    public static void main(String[ ] args) {
        SpringApplication.run(ClaveSpApplication.class, args);
    }

    /**
     * This method defines a bean that implements the CommandLineRunner interface. It is a mechanism that runs after the application context
     * has been initialized and allows additional code to be executed (for example, to inspect or manipulate beans).
     * When the application starts, this method obtains the names of all beans defined in the ApplicationContext and prints them to the log, organized alphabetically.
     * 
     * @param ctx ApplicationContext
     * @return CommandLineRunner
     */
    @Bean
    CommandLineRunner commandLineRunner(ApplicationContext ctx) {
        return args -> {
            logger.info("Let's inspect the beans provided by Spring Boot:");

            // Recupera los nombres de los beans.
            String[ ] beanNames = ctx.getBeanDefinitionNames();
            Arrays.sort(beanNames);
            for (String beanName: beanNames) {
                logger.info("beanName" + beanName);
            }
        };
    }

    /**
     * This method is overridden by SpringBootServletInitializer and is used when deploying the application to an external server (such as Tomcat or Jetty).
     * It allows you to configure the application when using a WAR file instead of a JAR.
     * The method takes a SpringApplicationBuilder and tells it that the application source is ClaveSpApplication.class.
     * This method is required so that Spring Boot can properly configure the application when running inside an external servlet container.
     * 
     * {@inheritDoc}
     * @see org.springframework.boot.web.servlet.support.SpringBootServletInitializer#configure(org.springframework.boot.builder.SpringApplicationBuilder)
     */
    @Override
    protected SpringApplicationBuilder configure(SpringApplicationBuilder builder) {
        return builder.sources(ClaveSpApplication.class);
    }
}
