/* 
/*******************************************************************************
 * Copyright (C) 2024 Secretaría General de la Administración Digital, Gobierno de España
 * This program is licensed and may be used, modified and redistributed under the  terms
 * of the European Public License (EUPL), either version 1.1 or (at your option)
 * any later version as soon as they are approved by the European Commission.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and
 * more details.
 * You should have received a copy of the EUPL1.1 license
 * along with this program; if not, you may find it at
 * http:joinup.ec.europa.eu/software/page/eupl/licence-eupl
 ******************************************************************************/

/** 
 * <b>File:</b><p>es.clave.SP2.IndexRequestController.java.</p>
 * <b>Description:</b><p>Class that runs when the initial indexPage.html page loads and that initially loads some of the configurable values ​​from the application.properties file.</p>
 * <b>Project:</b><p>Citizen identification and authentication platform.</p>
 * <b>Date:</b><p>03/10/2024.</p>
 * @author Gobierno de España.
 * @version 1.0, 03/10/2024.
 */
package es.clave.SP2;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;

/** 
 * <p>Class that runs when the initial indexPage.html page loads and that initially loads some of the configurable values ​​from the application.properties file.</p>
 * <b>Project:</b><p>Citizen identification and authentication platform.</p>
 * @version 1.0, 03/10/2024.
 */
@Controller
public class IndexRequestController {

    /**
     * Injecting the value 'request.providerName' from the application.properties file
     */
    @Value("${request.providerName}")
    private String providerName;

    /**
     * Injecting the value 'request.url' from the application.properties file
     */
    @Value("${request.url}")
    private String requestUrl;

    /**
     * Injecting the value 'request.returnURL' from the application.properties file
     */
    @Value("${request.returnURL}")
    private String returnURL;

    /**
     * Injecting the value 'request.application' from the application.properties file
     */
    @Value("${request.application}")
    private String application;

    /**
     * Function that is executed when the kit is invoked with the '/SP2' context only
     * 
     * @return Makes a redirect to the context '/SP2/IndexPage'
     */
    @GetMapping("/")
    public String home() {
        return "redirect:/IndexPage";
    }

    /**
     * Function that is executed when the kit is invoked with the '/SP2/IndexPage' context, from a GET type call
     * 
     * @param model
     * @return Displays the 'indexPage.html' Kit splash screen
     */
    @GetMapping("/IndexPage")
    public String requestForm(Model model) {
        RequestSAML req = new RequestSAML();
        req.setProviderName(providerName);
        req.setUrl(requestUrl);
        req.setReturnURL(returnURL);
        req.setApplication(application);
        model.addAttribute("request", req);

        return "indexPage";
    }

    /**
     * Function that is executed when the kit is invoked with the '/SP2/IndexPage' context, from a POST type call
     * 
     * @return Makes a redirect to the context '/SP2/IndexPage'
     */
    @PostMapping("/IndexPage")
    public String handleSubmit() {
        // Redirect to the index page without any parameters
        return "redirect:/IndexPage";
    }
}
