/* 
/*******************************************************************************
 * Copyright (C) 2024 Secretaría General de la Administración Digital, Gobierno de España
 * This program is licensed and may be used, modified and redistributed under the  terms
 * of the European Public License (EUPL), either version 1.1 or (at your option)
 * any later version as soon as they are approved by the European Commission.
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and
 * more details.
 * You should have received a copy of the EUPL1.1 license
 * along with this program; if not, you may find it at
 * http:joinup.ec.europa.eu/software/page/eupl/licence-eupl
 ******************************************************************************/

/** 
 * <b>File:</b><p>es.clave.SP2.util.MessagesPropertiesRetriever.java.</p>
 * <b>Description:</b><p>Class that is responsible for reading text messages from the 'messages.properties' file.</p>
 * <b>Project:</b><p>Citizen identification and authentication platform.</p>
 * <b>Date:</b><p>03/10/2024.</p>
 * @author Gobierno de España.
 * @version 1.0, 03/10/2024.
 */
package es.clave.SP2.util;

import java.util.ArrayList;
import java.util.Map;
import java.util.PropertyResourceBundle;
import java.util.function.Function;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

/** 
 * <p>Class that is responsible for reading text messages from the 'messages.properties' file.</p>
 * <b>Project:</b><p>Citizen identification and authentication platform.</p>
 * @version 1.0, 03/10/2024.
 */
@Component
public class MessagesPropertiesRetriever {
    private PropertyResourceBundle messagesProperties;
    
    public MessagesPropertiesRetriever(@Value("#{new java.util.PropertyResourceBundle(new java.io.InputStreamReader(new org.springframework.core.io.ClassPathResource('messages.properties').inputStream))}") PropertyResourceBundle messagesProperties) {
        this.messagesProperties = messagesProperties;
    }
    
    public Map<String, String> getMessagesProperties() {
        return messagesProperties.keySet().stream().collect(Collectors.toMap(Function.identity(), messagesProperties::getString));
    }

    public String getMessageWithMultipleProps(String keyMessage, ArrayList<String> valuesMultipleProps) {
        String message = getMessagesProperties().get(keyMessage);
        if (message != null) {
            for (int i = 0; i < valuesMultipleProps.size(); i++) {
                message = message.replace("{" + i + "}", valuesMultipleProps.get(i));
            }
            return message;
        }
        return "";
    }
}
